pub struct Cli {
pub render: Option<Render>,
pub text: Option<String>,
pub completion: Option<Shell>,
}Fields
render: Option<Render>Print QR codes using large, medium or small block characters
text: Option<String>File to read, or text to import, for QR code
completion: Option<Shell>Create completion script